@@ -387,18 +387,18 @@ class InspectDBTestCase(TestCase):
         Introspection of columns with a custom field (#21090)
         """
         out = StringIO()
-        orig_data_types_reverse = connection.introspection.data_types_reverse
-        try:
-            connection.introspection.data_types_reverse = {
+        with mock.patch(
+            "django.db.connection.introspection.data_types_reverse."
+            "base_data_types_reverse",
+            {
                 "text": "myfields.TextField",
                 "bigint": "BigIntegerField",
-            }
+            },
+        ):
             call_command("inspectdb", "inspectdb_columntypes", stdout=out)
             output = out.getvalue()
             self.assertIn("text_field = myfields.TextField()", output)
             self.assertIn("big_int_field = models.BigIntegerField()", output)
-        finally:
-            connection.introspection.data_types_reverse = orig_data_types_reverse
 
     def test_introspection_errors(self):
         """
