@@ -12,8 +12,9 @@ class DummyStorage(storage.Storage):
     A storage class that implements get_modified_time() but raises
     NotImplementedError for path().
     """
+
     def _save(self, name, content):
-        return 'dummy'
+        return "dummy"
 
     def delete(self, name):
         pass
@@ -26,9 +27,8 @@ class DummyStorage(storage.Storage):
 
 
 class PathNotImplementedStorage(storage.Storage):
-
     def _save(self, name, content):
-        return 'dummy'
+        return "dummy"
 
     def _path(self, name):
         return os.path.join(settings.STATIC_ROOT, name)
@@ -62,19 +62,19 @@ class NeverCopyRemoteStorage(PathNotImplementedStorage):
     """
     Return a future modified time for all files so that nothing is collected.
     """
+
     def get_modified_time(self, name):
         return datetime.now() + timedelta(days=30)
 
 
 class QueryStringStorage(storage.Storage):
     def url(self, path):
-        return path + '?a=b&c=d'
+        return path + "?a=b&c=d"
 
 
 class SimpleStorage(ManifestStaticFilesStorage):
-
     def file_hash(self, name, content=None):
-        return 'deploy12345'
+        return "deploy12345"
 
 
 class ExtraPatternsStorage(ManifestStaticFilesStorage):
@@ -82,9 +82,11 @@ class ExtraPatternsStorage(ManifestStaticFilesStorage):
     A storage class to test pattern substitutions with more than one pattern
     entry. The added pattern rewrites strings like "url(...)" to JS_URL("...").
     """
+
     patterns = tuple(ManifestStaticFilesStorage.patterns) + (
         (
-            "*.js", (
+            "*.js",
+            (
                 (
                     r"""(?P<matched>url\(['"]{0,1}\s*(?P<url>.*?)["']{0,1}\))""",
                     'JS_URL("%(url)s")',
